@@ -9,7 +9,7 @@
 #' @param ratio the proportion of the samples to use for calibration (default = 0.75).
 #' @param VIP.threshold thresholding to remove non-important variables (default = 1).
 #'
-#' @details Variables are first sorted with respect to some importancemeasure, 
+#' @details Variables are first sorted with respect to some importance measure, 
 #' and usually one of the filter measures described above are used. Secondly, a 
 #' threshold is used to eliminate a subset of the least informative variables. Then
 #' a model is fitted again to the remaining variables and performance is measured. 
@@ -112,13 +112,19 @@ bve_pls <- function( y, X, ncomp=10, ratio=0.75, VIP.threshold=1 ){
       VIP.index <- sort(Vip,decreasing=FALSE, index.return = T)$ix [1:ncomp]
     }
     is.selected[variables[VIP.index]] <- F
-    variables     <- which( is.selected ) 
-    Variable.list <- c(Variable.list, list(variables)) 
-    Zcal  <- Zcal[,VIP.index]
-    Ztest <- Ztest[,VIP.index]
+    variables     <- which( is.selected )
+    # Thanks to @tien-endotchang for reporting sign error.
+    Zcal  <- Zcal[,-VIP.index, drop=FALSE]
+    Ztest <- Ztest[,-VIP.index, drop=FALSE]
     indd  <- unique( which(apply(Zcal, 2, var)==0),which(apply(Ztest, 2, var)==0))
-    Zcal  <- Zcal[, -indd] 
-    Ztest <- Ztest[, -indd] 
+    # Thanks to @tien-endotchang for reporting possible 0-length indd error.
+    if(length(indd)>0){
+      is.selected[variables[indd]] <- F
+      variables <- which(is.selected)
+      Zcal  <- Zcal[, -indd] 
+      Ztest <- Ztest[, -indd]
+    }
+    Variable.list <- c(Variable.list, list(variables)) 
     if( ncol(Zcal) <= ncomp+1 ){  # terminates if less than 5 variables remain
       terminated <- TRUE
     } 
